@@ -42,7 +42,6 @@ module Api
       end
 
       before_action :setup_has_many_params, :only => [:create, :update]
-      before_action :check_media_type
 
       layout 'api/v2/layouts/index_layout', :only => :index
 
@@ -157,12 +156,6 @@ module Api
         append_array_of_ids(params)             # unwrapped params
       end
 
-      def check_media_type
-        if (request.post? || request.put?) && request.media_type != "application/json"
-          render_error(:unsupported_media_type, :status => :unsupported_media_type)
-        end
-      end
-
       def render_error(error, options = { })
         options = set_error_details(error, options)
         render options.merge(:template => "api/v2/errors/#{error}",
