@@ -232,7 +232,7 @@ class ApplicationController < ActionController::Base
   end
 
   def resource_base_with_search
-    resource_base.search_for(params[:search], :order => params[:order])
+    virtual_column_scope(resource_base) || resource_base.search_for(params[:search], :order => params[:order])
   end
 
   def resource_base_search_and_page(tables = [])
@@ -333,10 +333,6 @@ class ApplicationController < ActionController::Base
     render :partial => "common/ajax_error", :status => :internal_server_error, :locals => { :message => message }
   end
 
-  def redirect_back_or_to(url)
-    redirect_back(fallback_location: url, allow_other_host: false)
-  end
-
   def saved_redirect_url_or(default)
     session["redirect_to_url_#{controller_name}"] || default
   end
@@ -397,6 +393,11 @@ class ApplicationController < ActionController::Base
     Foreman::ParameterFilter::Context.new(:ui, controller_name, params[:action])
   end
 
+  def wrap_for_virt_column_select(base_scope)
+    scope = virtual_column_scope(base_scope) || base_scope.search_for(params[:search], :order => params[:order])
+    scope.paginate(:page => params[:page], :per_page => params[:per_page])
+  end
+
   class << self
     def parameter_filter_context
       Foreman::ParameterFilter::Context.new(:ui, controller_name, nil)
