@@ -1,6 +1,5 @@
 module Foreman::Controller::Parameters::Filter
   extend ActiveSupport::Concern
-  include Foreman::Controller::Parameters::Taxonomix
 
   class_methods do
     def filter_params_filter
@@ -8,11 +7,7 @@ module Foreman::Controller::Parameters::Filter
         filter.permit :resource_type,
           :role_id, :role_name,
           :search,
-          :taxonomy_search,
-          :unlimited,
-          :override,
           :permissions => [], :permission_ids => [], :permission_names => []
-        add_taxonomix_params_filter(filter)
       end
     end
   end
