@@ -36,21 +36,12 @@ module Foreman::Controller::TaxonomyMultiple
     end
 
     taxonomy = Taxonomy.find_by_id(id)
-
-    if params[type][:optimistic_import] == 'yes'
-      @hosts.update_all("#{type}_id".to_sym => taxonomy.id)
-      # hosts location needs to be updated before import missing ids
-      taxonomy.import_missing_ids
-    else
-      if taxonomy.need_to_be_selected_ids.count == 0
-        @hosts.update_all("#{type}_id".to_sym => taxonomy.id)
-      else
-        error "Cannot update #{taxonomy.type} to #{taxonomy.name} because of mismatch in settings"
-        redirect_back_or_to helpers.current_hosts_path
-        return
-      end
+    begin
+      BulkHostsManager.new(hosts: @hosts).assign_taxonomy(taxonomy, params[type][:optimistic_import] == 'yes')
+      success "Updated hosts: Changed #{type.to_s.classify}"
+    rescue => e
+      error e.message
     end
-    success "Updated hosts: Changed #{type.to_s.classify}"
     redirect_back_or_to helpers.current_hosts_path
   end
 end
