@@ -453,10 +453,7 @@ class HostsController < ApplicationController
     end
 
     # update the hosts
-    @hosts.each do |host|
-      host.is_owned_by = id
-      host.save(:validate => false)
-    end
+    BulkHostsManager.new(hosts: @hosts).change_owner(id)
 
     success _('Updated hosts: changed owner')
     redirect_back_or_to helpers.current_hosts_path
@@ -554,9 +551,7 @@ class HostsController < ApplicationController
   end
 
   def update_multiple_disassociate
-    @hosts.each do |host|
-      host.disassociate!
-    end
+    BulkHostsManager.new(hosts: @hosts).disassociate
     success _('Updated hosts: Disassociated from VM')
     redirect_back_or_to helpers.current_hosts_path
   end
@@ -616,12 +611,22 @@ class HostsController < ApplicationController
   # we don't need any has_many relation to determine what proxies are used and the view
   # renders only resulting templates set so the rest of form is unaffected
   def template_used
-    host = params[:id] ? Host::Base.readonly.find(params[:id]) : Host.new
+    host = params[:id] ? Host::Base.readonly.find(params[:id]) : Host.new(host_params)
     kind = params.delete(:provisioning)
     host.attributes = host_attributes_for_templates(host)
     templates = host.available_template_kinds(kind)
+
     return not_found if templates.empty?
-    render :partial => 'provisioning', :locals => { :templates => templates }
+
+    rendered_errors = {}
+    ok_tmpl, err_tmpl = templates.partition do |t|
+      t.render(host: host)
+    rescue => e
+      rendered_errors[t.id] = e.message
+      false
+    end
+
+    render partial: 'provisioning', locals: { ok_tmpl: ok_tmpl, err_tmpl: err_tmpl, rendered_errors: rendered_errors }
   end
 
   def preview_host_collection
@@ -643,7 +648,7 @@ class HostsController < ApplicationController
       captions: HostStatus.status_registry.map do |status_class|
         status_class.status_name
       end,
-      statuses: host_statuses.map do |status|
+      statuses: host_statuses.select(&:relevant?).map do |status|
         {
           id: status.id,
           name: status.name,
