@@ -3,8 +3,9 @@ class LinksController < ApplicationController
   before_action :validate_root_url
 
   def show
-    url = external_url(type: params[:type], options: params)
-    redirect_to(url)
+    permitted = params.permit(:type, :section, :chapter, :flavor, :root_url)
+    url = external_url(type: permitted[:type], options: permitted)
+    redirect_to(url, allow_other_host: true)
   end
 
   def external_url(type:, options: {})
@@ -27,9 +28,13 @@ class LinksController < ApplicationController
       'https://www.vmware.com/go/download-vmrc'
     when 'docs'
       params.require(:section)
-      guide, chapter, flavor = params.permit(:section, :chapter, :flavor).values_at(:section, :chapter, :flavor)
+      guide, chapter, flavor = options.values_at(:section, :chapter, :flavor)
       flavor ||= self.class.new_docs_flavor
       docs_url(guide: guide, chapter: chapter, flavor: flavor)
+    when 'upgrade'
+      upgrade_url(params[:section])
+    when 'support'
+      support_url
     end
   end
 
@@ -90,4 +95,12 @@ class LinksController < ApplicationController
   def wiki_url(section: '')
     "https://projects.theforeman.org/projects/foreman/wiki/#{section}"
   end
+
+  def support_url
+    forum_url('c/support')
+  end
+
+  def upgrade_url(section)
+    docs_url(guide: 'Upgrading_Project', flavor: self.class.new_docs_flavor)
+  end
 end
