@@ -253,16 +253,17 @@ Foreman::Application.routes.draw do
       get 'extlogout'
       get 'auto_complete_search'
       delete 'stop_impersonation'
+      delete 'invalidate_jwt_for_all_users'
     end
     member do
       post 'impersonate'
+      patch 'invalidate_jwt'
     end
     resources :ssh_keys, only: [:new, :create, :destroy]
   end
   resources :roles, except: [:show] do
     member do
       get 'clone'
-      patch 'disable_filters_overriding'
     end
     collection do
       get 'auto_complete_search'
@@ -271,7 +272,6 @@ Foreman::Application.routes.draw do
 
   resources :filters, except: [:show, :new, :edit] do
     member do
-      patch 'disable_overriding'
       get 'edit', to: 'react#index'
     end
     collection do
@@ -559,4 +559,5 @@ Foreman::Application.routes.draw do
 
   get 'page-not-found' => 'react#index'
   get 'links/:type(/:section)' => 'links#show', :as => 'external_link', :constraints => { section: %r{.*} }
+  get 'upgrade' => 'react#index'
 end
