@@ -27,11 +27,6 @@ class PxeLoaderSupportTest < ActiveSupport::TestCase
       assert_equal :PXELinux, @subject.pxe_loader_kind(@host)
     end
 
-    test "PXEGrub is found for given filename" do
-      @host.pxe_loader = "grub/grubx64.efi"
-      assert_equal :PXEGrub, @subject.pxe_loader_kind(@host)
-    end
-
     test "PXEGrub2 is found for grubx64.elf filename" do
       @host.pxe_loader = "grub2/grubx64.elf"
       assert_equal :PXEGrub2, @subject.pxe_loader_kind(@host)
@@ -62,11 +57,6 @@ class PxeLoaderSupportTest < ActiveSupport::TestCase
       assert_equal :PXELinux, @subject.pxe_loader_kind(@host)
     end
 
-    test "PXEGrub is found for given loader name" do
-      @host.pxe_loader = "Grub UEFI"
-      assert_equal :PXEGrub, @subject.pxe_loader_kind(@host)
-    end
-
     test "PXEGrub2 is found for EFI loader name" do
       @host.pxe_loader = "Grub2 UEFI"
       assert_equal :PXEGrub2, @subject.pxe_loader_kind(@host)
@@ -127,6 +117,16 @@ class PxeLoaderSupportTest < ActiveSupport::TestCase
       assert_equal :iPXE, @subject.pxe_loader_kind(@host)
     end
 
+    test "iPXE is found for iPXE Chain UEFI" do
+      @host.pxe_loader = "iPXE Chain UEFI"
+      assert_equal :iPXE, @subject.pxe_loader_kind(@host)
+    end
+
+    test "iPXE is found for ipxe-x64.efi" do
+      @host.pxe_loader = "ipxe-x64.efi"
+      assert_equal :iPXE, @subject.pxe_loader_kind(@host)
+    end
+
     test "iPXE is found for undionly.kpxe filename" do
       @host.pxe_loader = 'undionly.kpxe'
       assert_equal :iPXE, @subject.pxe_loader_kind(@host)
@@ -136,7 +136,6 @@ class PxeLoaderSupportTest < ActiveSupport::TestCase
   describe "preferred loader" do
     setup do
       @template_pxelinux = FactoryBot.create(:provisioning_template, :template_kind => TemplateKind.find_by_name(:PXELinux))
-      @template_pxegrub = FactoryBot.create(:provisioning_template, :template_kind => TemplateKind.find_by_name(:PXEGrub))
       @template_pxegrub2 = FactoryBot.create(:provisioning_template, :template_kind => TemplateKind.find_by_name(:PXEGrub2))
       @template_ipxe = FactoryBot.create(:provisioning_template, :template_kind => TemplateKind.find_by_name(:iPXE))
     end
@@ -154,17 +153,12 @@ class PxeLoaderSupportTest < ActiveSupport::TestCase
 
     test "is none for zero template kinds" do
       @subject.expects(:template_kinds).returns([])
-      @subject.expects(:os_default_templates).returns([@template_pxelinux, @template_pxegrub, @template_pxegrub2])
+      @subject.expects(:os_default_templates).returns([@template_pxelinux, @template_pxegrub2])
       assert_nil @subject.preferred_loader
     end
 
     test "is PXELinux for all associated template kinds" do
-      @subject.expects(:os_default_templates).returns([@template_pxelinux, @template_pxegrub, @template_pxegrub2])
-      assert_equal "PXELinux BIOS", @subject.preferred_loader
-    end
-
-    test "is PXELinux for associated PXELinux and PXEGrub" do
-      @subject.expects(:os_default_templates).returns([@template_pxelinux, @template_pxegrub])
+      @subject.expects(:os_default_templates).returns([@template_pxelinux, @template_pxegrub2])
       assert_equal "PXELinux BIOS", @subject.preferred_loader
     end
 
@@ -173,11 +167,6 @@ class PxeLoaderSupportTest < ActiveSupport::TestCase
       assert_equal "Grub2 UEFI", @subject.preferred_loader
     end
 
-    test "is PXEGrub for associated template PXEGrub" do
-      @subject.expects(:os_default_templates).returns([@template_pxegrub])
-      assert_equal "Grub UEFI", @subject.preferred_loader
-    end
-
     test "is iPXE Chain BIOS for associated template iPXE" do
       @subject.expects(:os_default_templates).returns([@template_ipxe])
       assert_equal "iPXE Chain BIOS", @subject.preferred_loader
