@@ -263,7 +263,6 @@ class OperatingsystemTest < ActiveSupport::TestCase
 
   test "provides available loaders for Redhat" do
     assert Redhat.new.available_loaders.include? "PXELinux BIOS"
-    assert Redhat.new.available_loaders.include? "Grub UEFI"
     assert Redhat.new.available_loaders.include? "Grub2 UEFI"
   end
 
@@ -284,9 +283,9 @@ class OperatingsystemTest < ActiveSupport::TestCase
     assert_equal "PXELinux BIOS", os.preferred_loader
   end
 
-  test "should have preferred pxe loader for OS with Grub template" do
-    os = FactoryBot.create(:operatingsystem, :with_associations, :with_grub)
-    assert_equal "Grub UEFI", os.preferred_loader
+  test "should have preferred pxe loader for OS with Grub2 template" do
+    os = FactoryBot.create(:operatingsystem, :with_associations, :with_grub2)
+    assert_equal "Grub2 UEFI", os.preferred_loader
   end
 
   test "additional_media returns media from medium provider" do
@@ -379,13 +378,13 @@ class OperatingsystemTest < ActiveSupport::TestCase
     test 'should be the smart proxy and httpboot port for UEFI HTTP' do
       SmartProxy.any_instance.expects(:setting).with(:HTTPBoot, 'http_port').returns(1234)
       host = FactoryBot.build(:host, :managed, :with_tftp_and_httpboot_subnet, pxe_loader: 'Grub2 UEFI HTTP')
-      assert_match(%r{http://somewhere.*net:1234/httpboot/grub2/grubx64.efi}, host.operatingsystem.boot_filename(host))
+      assert_match(%r{http://somewhere.*net:1234/httpboot/@@subdir@@/grub2/grubx64.efi}, host.operatingsystem.boot_filename(host))
     end
 
     test 'should be the smart proxy and httpboot port for UEFI HTTPS' do
       SmartProxy.any_instance.expects(:setting).with(:HTTPBoot, 'https_port').returns(1235)
       host = FactoryBot.build(:host, :managed, :with_tftp_and_httpboot_subnet, pxe_loader: 'Grub2 UEFI HTTPS')
-      assert_match(%r{https://somewhere.*net:1235/httpboot/grub2/grubx64.efi}, host.operatingsystem.boot_filename(host))
+      assert_match(%r{https://somewhere.*net:1235/httpboot/@@subdir@@/grub2/grubx64.efi}, host.operatingsystem.boot_filename(host))
     end
 
     test 'should not raise an error without httpboot feature for PXE' do
