@@ -19,23 +19,14 @@ class AuthorizerTest < ActiveSupport::TestCase
     [true, false].each do |cache|
       context "with cache = #{cache}" do
         context 'without subject' do
-          # limited, unlimited, permission with resource, without resource...
-          test "with unlimited filter" do
+          # permission with resource, without resource...
+          test "with filter" do
             FactoryBot.create(:filter, :role => @role, :permissions => [@permission])
             auth = Authorizer.new(@user)
 
             assert auth.can?(@permission.name.to_sym, nil, cache)
             refute auth.can?(:view_domains, nil, cache)
           end
-
-          test "with limited filter (name ~ *)" do
-            FactoryBot.create(:filter, :on_name_all, :role => @role, :permissions => [@permission])
-            auth = Authorizer.new(@user)
-
-            assert auth.can?(@permission.name.to_sym, nil, cache)
-            refute auth.can?(:view_domains, nil, cache)
-          end
-
           test "permission without resource" do
             FactoryBot.create(:filter, :on_name_all, :role => @role, :permissions => [@permission])
             auth = Authorizer.new(@user)
@@ -53,7 +44,7 @@ class AuthorizerTest < ActiveSupport::TestCase
         end
 
         context 'with subject (e.g: Domain)' do
-          test "unlimited filter" do
+          test "filter" do
             permission = Permission.find_by_name('view_domains')
             FactoryBot.create(:filter, :role => @role, :permissions => [permission])
             domain     = FactoryBot.create(:domain)
@@ -63,18 +54,7 @@ class AuthorizerTest < ActiveSupport::TestCase
             assert auth.can?(:view_domains, domain, cache)
           end
 
-          test "matching limited filter" do
-            permission = Permission.find_by_name('view_domains')
-            FactoryBot.create(:filter, :role => @role, :permissions => [permission],
-                               :search => 'name ~ example*')
-            domain     = FactoryBot.create(:domain)
-            auth       = Authorizer.new(@user)
-
-            assert_includes auth.find_collection(Domain, :permission => :view_domains), domain
-            assert auth.can?(:view_domains, domain, cache)
-          end
-
-          test "matching and not matching limited filter" do
+          test "matching and not matching filter" do
             permission = Permission.find_by_name('view_domains')
             FactoryBot.create(:filter, :role => @role, :permissions => [permission],
                                :search => 'name ~ noexample*')
@@ -87,7 +67,7 @@ class AuthorizerTest < ActiveSupport::TestCase
             assert auth.can?(:view_domains, domain, cache)
           end
 
-          test "not matching limited filter" do
+          test "not matching filter" do
             permission = Permission.find_by_name('view_domains')
             FactoryBot.create(:filter, :role => @role, :permissions => [permission],
                                :search        => 'name ~ noexample*')
@@ -98,7 +78,7 @@ class AuthorizerTest < ActiveSupport::TestCase
             refute auth.can?(:view_domains, domain, cache)
           end
 
-          test "filters records by matching limited filter" do
+          test "filters records by matching filter" do
             permission = Permission.find_by_name('view_domains')
             FactoryBot.create(:filter, :on_name_starting_with_a,
               :role => @role, :permissions => [permission])
@@ -143,8 +123,7 @@ class AuthorizerTest < ActiveSupport::TestCase
             refute auth.can?(:edit_domains, domain2, cache)
             refute auth.can?(:edit_domains, domain3, cache)
             assert auth.can?(:edit_domains, domain4, cache)
-
-            # unlimited filter on Domain permission does add the domain
+            # filter on Domain permission does add the domain
             FactoryBot.create(:filter, :role => @role, :permissions => [permission1])
             collection = auth.find_collection(Domain)
             assert_includes collection, domain1
@@ -228,43 +207,47 @@ class AuthorizerTest < ActiveSupport::TestCase
   end
 
   test "#build_scoped_search_condition(filters) for one filter" do
-    auth    = Authorizer.new(FactoryBot.create(:user))
+    user = FactoryBot.create(:user)
+    auth    = Authorizer.new(user)
     filters = [FactoryBot.build_stubbed(:filter, :on_name_all)]
     result  = auth.build_scoped_search_condition(filters)
 
-    assert_equal '(name ~ *)', result
+    assert_equal "(((name ~ *)) AND ((organization_id ^ (#{user.organization_ids.first})) AND (location_id ^ (#{user.location_ids.first}))))", result
   end
 
   test "#build_scoped_search_condition(filters) for more filters" do
-    auth    = Authorizer.new(FactoryBot.create(:user))
+    user = FactoryBot.create(:user)
+    auth    = Authorizer.new(user)
     filters = [FactoryBot.build_stubbed(:filter, :on_name_all), FactoryBot.build_stubbed(:filter, :on_name_starting_with_a)]
     result  = auth.build_scoped_search_condition(filters)
-
-    assert_equal '(name ~ *) OR (name ~ a*)', result
+    assert_equal result, "(((name ~ *) OR (name ~ a*)) AND ((organization_id ^ (#{user.organization_ids.first})) AND (location_id ^ (#{user.location_ids.first}))))"
   end
 
-  test "#build_scoped_search_condition(filters) for unlimited filter" do
-    auth    = Authorizer.new(FactoryBot.create(:user))
+  test "#build_scoped_search_condition(filters) for filter" do
+    user = FactoryBot.create(:user)
+    auth    = Authorizer.new(user)
     filters = [FactoryBot.build_stubbed(:filter)]
     result  = auth.build_scoped_search_condition(filters)
 
-    assert_equal '', result
+    assert_equal "(((organization_id ^ (#{user.organization_ids.first})) AND (location_id ^ (#{user.location_ids.first}))))", result
   end
 
   test "#build_scoped_search_condition(filters) for limited and unlimited filter" do
-    auth    = Authorizer.new(FactoryBot.create(:user))
+    user = FactoryBot.create(:user)
+    auth    = Authorizer.new(user)
     filters = [FactoryBot.build_stubbed(:filter, :on_name_all), FactoryBot.build_stubbed(:filter)]
     result  = auth.build_scoped_search_condition(filters)
 
-    assert_equal '(name ~ *)', result
+    assert_equal "(((organization_id ^ (#{user.organization_ids.first})) AND (location_id ^ (#{user.location_ids.first}))))", result
   end
 
   test "#build_scoped_search_condition(filters) for empty filter" do
-    auth    = Authorizer.new(FactoryBot.create(:user))
-    filters = [FactoryBot.build_stubbed(:filter, :search => '')]
+    user = FactoryBot.create(:user)
+    auth    = Authorizer.new(user)
+    filters = [FactoryBot.build_stubbed(:filter, :search => nil)]
     result  = auth.build_scoped_search_condition(filters)
 
-    assert_equal '', result
+    assert_equal "(((organization_id ^ (#{user.organization_ids.first})) AND (location_id ^ (#{user.location_ids.first}))))", result
   end
 
   test "#find_collection(Host, :permission => :view_hosts) with scoped_search join returns r/w resources" do
@@ -289,9 +272,9 @@ class AuthorizerTest < ActiveSupport::TestCase
     assert_includes auth.find_collection(Host::Managed, :permission => :view_hosts, :joined_on => Report), report
   end
 
-  test "#find_collection(Host, :permission => :view_hosts, :joined_on: Report) for matching unlimited filter" do
+  test "#find_collection(Host, :permission => :view_hosts, :joined_on: Report) for matching filter" do
     permission = Permission.find_by_name('view_hosts')
-    FactoryBot.create(:filter, :role => @role, :permissions => [permission], :unlimited => true)
+    FactoryBot.create(:filter, :role => @role, :permissions => [permission])
     host       = FactoryBot.create(:host)
     report     = FactoryBot.create(:config_report, :host => host)
     auth       = Authorizer.new(@user)
@@ -299,17 +282,6 @@ class AuthorizerTest < ActiveSupport::TestCase
     assert_includes auth.find_collection(Host::Managed, :permission => :view_hosts, :joined_on => Report), report
   end
 
-  test "#find_collection(Host, :permission => :view_hosts, :joined_on: Report) for matching limited filter" do
-    permission = Permission.find_by_name('view_hosts')
-    FactoryBot.create(:filter, :role => @role, :permissions => [permission],
-                                :search => 'hostgroup ~ hostgroup*')
-    host       = FactoryBot.create(:host, :with_hostgroup)
-    report     = FactoryBot.create(:config_report, :host => host)
-    auth       = Authorizer.new(@user)
-
-    assert_includes auth.find_collection(Host::Managed, :permission => :view_hosts, :joined_on => Report), report
-  end
-
   test "#find_collection(Host, :permission => :view_hosts, :joined_on: Report) for matching limited filter with base collection set" do
     permission = Permission.find_by_name('view_hosts')
     FactoryBot.create(:filter, :role => @role, :permissions => [permission],
@@ -326,7 +298,7 @@ class AuthorizerTest < ActiveSupport::TestCase
 
   test "#find_collection(Host, :permission => :view_hosts, :joined_on: Report, :where => ..) applies where clause" do
     permission = Permission.find_by_name('view_hosts')
-    FactoryBot.create(:filter, :role => @role, :permissions => [permission], :unlimited => true)
+    FactoryBot.create(:filter, :role => @role, :permissions => [permission])
     hosts      = FactoryBot.create_pair(:host)
     report1    = FactoryBot.create(:config_report, :host => hosts.first)
     report2    = FactoryBot.create(:config_report, :host => hosts.last)
@@ -340,7 +312,7 @@ class AuthorizerTest < ActiveSupport::TestCase
 
   test "#find_collection(Host::Base) works with taxonomies thanks to class name sanitization" do
     permission = Permission.find_by_name('view_hosts')
-    FactoryBot.create(:filter, :role => @role, :permissions => [permission], :unlimited => true, :organization_ids => [taxonomies(:organization1).id])
+    FactoryBot.create(:filter, :role => @role, :permissions => [permission])
     auth = Authorizer.new(@user)
 
     assert_nothing_raised do
@@ -361,7 +333,7 @@ class AuthorizerTest < ActiveSupport::TestCase
       test 'allows filtering on associations that do not match association class' do
         permission = Permission.find_by_name('view_hosts')
         FactoryBot.create(:host, :debian, :with_facts)
-        FactoryBot.create(:filter, role: @role, permissions: [permission], search: 'os = Debian', organization_ids: [taxonomies(:organization1).id])
+        FactoryBot.create(:filter, role: @role, permissions: [permission], search: 'os = Debian')
         authorizer = Authorizer.new(@user)
         # FactValue is referencing HostBase, but operatingsystem association is defined on Host::Managed
         # this could cause unknown association exception in Rails, we should avoid it
@@ -371,5 +343,56 @@ class AuthorizerTest < ActiveSupport::TestCase
         assert_operator 0, :<, authorizer.find_collection(Host, permission: :view_hosts, joined_on: FactValue).count
       end
     end
+
+    context 'user taxonomy scoping' do
+      setup do
+        as_admin do
+          @org1 = FactoryBot.create(:organization)
+          @org2 = FactoryBot.create(:organization)
+          @loc1 = FactoryBot.create(:location)
+          @loc2 = FactoryBot.create(:location)
+          @user_role  = FactoryBot.create(:user_user_role)
+          @user       = @user_role.owner
+          @role       = @user_role.role
+        end
+      end
+
+      test 'user should not see resource from a different org' do
+        permission = Permission.find_by_name('view_domains')
+        domain = FactoryBot.create(:domain, organization_ids: [@org1.id])
+        FactoryBot.create(:filter, role: @role, permissions: [permission], search: "name = #{domain.name}")
+
+        assert_predicate (domain.organization_ids & @user.organization_ids), :empty?, 'user and domain do not share any organization'
+
+        User.current = @user
+        assert_empty ::Domain.unscoped.authorized(:view_domains)
+      end
+
+      test 'user should see resource in the same org' do
+        permission = Permission.find_by_name('view_domains')
+        domain = FactoryBot.create(:domain)
+        FactoryBot.create(:filter, role: @role, permissions: [permission], search: "name = #{domain.name}")
+
+        assert_predicate (domain.organization_ids & @user.organization_ids), :any?, 'user and domain share at least one organization'
+
+        User.current = @user
+        assert_equal [domain.id], ::Domain.unscoped.authorized(:view_domains).map(&:id)
+      end
+
+      test 'user should see resource in a child org' do
+        permission = Permission.find_by_name('view_domains')
+        child_org = FactoryBot.create(:organization)
+        child_org.parent_id = @user.organization_ids.first
+        child_org.save!
+
+        domain = FactoryBot.create(:domain, organization_ids: [child_org.id])
+        FactoryBot.create(:filter, role: @role, permissions: [permission], search: "name = #{domain.name}")
+
+        assert_predicate (domain.organization_ids & @user.organization_ids), :empty?, 'user and domain do not share any organization'
+
+        User.current = @user
+        assert_equal [domain.id], ::Domain.unscoped.authorized(:view_domains).map(&:id)
+      end
+    end
   end
 end
