@@ -1,5 +1,9 @@
 import 'core-js/shim';
 import 'regenerator-runtime/runtime';
+import Cookies from 'js-cookie';
+import jstz from 'jstz';
+import ipaddr from 'ipaddr.js';
+import diff from 'diff';
 
 import compute from './foreman_compute_resource';
 import componentRegistry from './react_app/components/componentRegistry';
@@ -56,4 +60,9 @@ window.tfm = Object.assign(window.tfm || {}, {
   componentRegistry,
   store,
   lookupKeys,
+  Cookies,
 });
+
+window.jstz = jstz;
+window.ipaddr = ipaddr;
+window.diff = diff;
