@@ -1,17 +1,17 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Col } from 'patternfly-react';
+import { GridItem } from '@patternfly/react-core';
 import ShowTaxonomyInline from './ShowTaxonomyInline';
 import { translate as __ } from '../../common/I18n';
 
 const ShowOrgsLocs = ({ orgs, locs }) => (
-  <Col sm={10} className="taxonomy-section">
+  <GridItem span={12} className="taxonomy-section">
     <ShowTaxonomyInline
       displayLabel={__('Affected Organizations')}
       items={orgs}
     />
     <ShowTaxonomyInline displayLabel={__('Affected Locations')} items={locs} />
-  </Col>
+  </GridItem>
 );
 
 ShowOrgsLocs.propTypes = {
