@@ -1,5 +1,5 @@
 import React from 'react';
-import { mount } from '@theforeman/test';
+import { mount } from 'enzyme';
 import { testComponentSnapshotsWithFixtures } from '../../../../common/testHelpers';
 
 import EditorNavbar from '../EditorNavbar';
