@@ -1,14 +1,16 @@
 import PropTypes from 'prop-types';
 import React from 'react';
 import { PowerOffIcon } from '@patternfly/react-icons';
-import { Spinner } from '@patternfly/react-core';
+import { Spinner, Icon } from '@patternfly/react-core';
 import { STATUS } from '../../../../constants';
 
 const PowerStatusIcon = ({ state, responseStatus }) => {
   if (responseStatus === STATUS.PENDING) return <Spinner size="md" />;
   return (
     <span className={`power-${state}`}>
-      <PowerOffIcon id="power-status-icon" className={`power-${state}`} />
+      <Icon id="power-status-icon" className={`power-${state}`}>
+        <PowerOffIcon />
+      </Icon>
     </span>
   );
 };
