@@ -5,14 +5,18 @@ import { Tr, Td, ActionsColumn } from '@patternfly/react-table';
 import {
   ToolbarItem,
   Divider,
-  MenuItem,
   Flex,
   FlexItem,
   Button,
+  Menu,
+  MenuItem,
+  MenuContent,
+  MenuList,
   Split,
   SplitItem,
   TextContent,
   Text,
+  Icon,
 } from '@patternfly/react-core';
 import {
   Dropdown,
@@ -42,16 +46,23 @@ import { deleteHost } from '../HostDetails/ActionsBar/actions';
 import {
   useForemanSettings,
   useForemanHostsPageUrl,
+  useForemanContext,
 } from '../../Root/Context/ForemanContext';
 import { bulkDeleteHosts } from './BulkActions/bulkDelete';
+import {
+  BulkAssignOrganizationModalScene as BulkAssignOrganizationModal,
+  BulkAssignLocationModalScene as BulkAssignLocationModal,
+} from './BulkActions/assignTaxonomy';
 import BulkBuildHostModal from './BulkActions/buildHosts';
 import BulkReassignHostgroupModal from './BulkActions/reassignHostGroup';
+import BulkChangeOwnerModal from './BulkActions/changeOwner';
+import BulkDisassociateModal from './BulkActions/disassociate';
 import { foremanUrl } from '../../common/helpers';
 import Slot from '../common/Slot';
 import forceSingleton from '../../common/forceSingleton';
 import './index.scss';
 import { STATUS } from '../../constants';
-import { RowSelectTd } from './RowSelectTd';
+import { RowSelectTd } from '../PF4/TableIndexPage/RowSelectTd';
 import {
   useCurrentUserTablePreferences,
   useSetParamsAndApiAndSearch,
@@ -88,6 +99,7 @@ const HostsIndex = () => {
     apiOptions,
     defaultParams,
   });
+  const contextData = useForemanContext();
 
   const {
     response: {
@@ -134,21 +146,23 @@ const HostsIndex = () => {
   const columns = filterColumnDataByUserPreferences(
     isLoading,
     userColumns,
-    allColumns
+    allColumns,
+    contextData
   );
   const [columnNamesKeys, keysToColumnNames] = getColumnHelpers(columns);
-
   const columnSelectData = categoriesFromFrontendColumnData({
     registeredColumns: allColumns,
     userId: currentUserId,
     tableName: 'hosts',
     userColumns,
     hasPreference,
+    contextData,
   });
 
   const { pageRowCount } = getPageStats({ total, page, perPage });
   const {
     fetchBulkParams,
+    searchQuery,
     updateSearchQuery,
     ...selectAllOptions
   } = useBulkSelect({
@@ -166,7 +180,9 @@ const HostsIndex = () => {
     areAllRowsOnPageSelected,
     areAllRowsSelected,
     isSelected,
+    selectedResults,
   } = selectAllOptions;
+  const selectAllHostsMode = areAllRowsSelected() && searchQuery === '';
 
   const selectionToolbar = (
     <ToolbarItem key="selectAll">
@@ -204,6 +220,16 @@ const HostsIndex = () => {
   };
 
   useEffect(() => {
+    dispatch(
+      addModal({
+        id: 'bulk-assign-organization-modal',
+      })
+    );
+    dispatch(
+      addModal({
+        id: 'bulk-assign-location-modal',
+      })
+    );
     dispatch(
       addModal({
         id: 'bulk-build-hosts-modal',
@@ -214,14 +240,36 @@ const HostsIndex = () => {
         id: 'bulk-reassign-hg-modal',
       })
     );
+    dispatch(
+      addModal({
+        id: 'bulk-change-owner-modal',
+      })
+    );
+    dispatch(
+      addModal({
+        id: 'bulk-disassociate-modal',
+      })
+    );
   }, [dispatch]);
 
+  const { setModalOpen: setOrganizationModalOpen } = useForemanModal({
+    id: 'bulk-assign-organization-modal',
+  });
+  const { setModalOpen: setLocationModalOpen } = useForemanModal({
+    id: 'bulk-assign-location-modal',
+  });
   const { setModalOpen: setHgModalOpen } = useForemanModal({
     id: 'bulk-reassign-hg-modal',
   });
   const { setModalOpen: setBuildModalOpen } = useForemanModal({
     id: 'bulk-build-hosts-modal',
   });
+  const { setModalOpen: setChangeOwnerModalOpen } = useForemanModal({
+    id: 'bulk-change-owner-modal',
+  });
+  const { setModalOpen: setDisassociateModalOpen } = useForemanModal({
+    id: 'bulk-disassociate-modal',
+  });
 
   const dropdownItems = [
     <MenuItem
@@ -233,12 +281,68 @@ const HostsIndex = () => {
       {__('Build management')}
     </MenuItem>,
     <MenuItem
-      itemId="reassign-hg-dropdown-item"
-      key="reassign-hg-dropdown-item"
-      onClick={setHgModalOpen}
+      itemId="disassociate-dropdown-item"
+      key="disassociate-dropdown-item"
+      onClick={setDisassociateModalOpen}
       isDisabled={selectedCount === 0}
     >
-      {__('Change host group')}
+      {__('Disassociate hosts')}
+    </MenuItem>,
+    <MenuItem
+      itemId="host-association-dropdown-item"
+      key="host-association-dropdown-item"
+      isDisabled={selectedCount === 0}
+      flyoutMenu={
+        <Menu
+          ouiaId="host-association-dropdown-menu"
+          onSelect={() => setMenuOpen(false)}
+        >
+          <MenuContent>
+            <MenuList>
+              <MenuItem
+                itemId="reassign-hg-dropdown-item"
+                key="reassign-hg-dropdown-item"
+                onClick={setHgModalOpen}
+                isDisabled={selectedCount === 0}
+              >
+                {__('Host group')}
+              </MenuItem>
+              <Slot
+                id="_host-associations"
+                fetchBulkParams={fetchBulkParams}
+                selectedCount={selectedCount}
+                multi
+              />
+              <MenuItem
+                itemId="change-owner-dropdown-item"
+                key="change-owner-dropdown-item"
+                onClick={setChangeOwnerModalOpen}
+                isDisabled={selectedCount === 0}
+              >
+                {__('Owner')}
+              </MenuItem>
+              <MenuItem
+                itemId="assign-organization-dropdown-item"
+                key="assign-organization-dropdown-item"
+                onClick={setOrganizationModalOpen}
+                isDisabled={selectedCount === 0}
+              >
+                {__('Organization')}
+              </MenuItem>
+              <MenuItem
+                itemId="assign-location-dropdown-item"
+                key="assign-location-dropdown-item"
+                onClick={setLocationModalOpen}
+                isDisabled={selectedCount === 0}
+              >
+                {__('Location')}
+              </MenuItem>
+            </MenuList>
+          </MenuContent>
+        </Menu>
+      }
+    >
+      {__('Change associations')}
     </MenuItem>,
   ];
 
@@ -326,7 +430,11 @@ const HostsIndex = () => {
           ouiaId="legacy-ui-link-dropdown-item"
           key="legacy-ui-link-dropdown-item"
           href="/hosts"
-          icon={<UndoIcon />}
+          icon={
+            <Icon>
+              <UndoIcon />
+            </Icon>
+          }
         >
           {__('Legacy UI')}
         </DropdownItem>,
@@ -438,10 +546,19 @@ const HostsIndex = () => {
         })}
       </Table>
       <ForemanActionsBarContext.Provider
-        value={{ selectedCount, fetchBulkParams }}
+        value={{
+          selectAllHostsMode,
+          selectedCount,
+          selectedResults,
+          fetchBulkParams,
+        }}
       >
+        <BulkAssignOrganizationModal key="bulk-assign-organization-modal" />
+        <BulkAssignLocationModal key="bulk-assign-location-modal" />
         <BulkBuildHostModal key="bulk-build-hosts-modal" />
         <BulkReassignHostgroupModal key="bulk-reassign-hg-modal" />
+        <BulkChangeOwnerModal key="bulk-change-owner-modal" />
+        <BulkDisassociateModal key="bulk-disassociate-modal" />
         <Slot id="_all-hosts-modals" multi />
       </ForemanActionsBarContext.Provider>
     </TableIndexPage>
