@@ -1,15 +1,11 @@
 export const alerts = { error: 'some-error' };
-export const backgroundUrl = '/some-background';
 export const caption = 'some caption';
 export const logoSrc = '/some-logo';
 export const token = 'some token';
-export const version = 'some version';
 
 export const props = {
   alerts,
-  backgroundUrl,
   caption,
   logoSrc,
   token,
-  version,
 };
