@@ -1,6 +1,6 @@
 import React from 'react';
 import { PlusIcon } from '@patternfly/react-icons';
-import { Spinner } from '@patternfly/react-core';
+import { Spinner, Icon } from '@patternfly/react-core';
 import {
   DropdownItem,
   DropdownGroup,
@@ -11,7 +11,7 @@ import { STATUS } from '../../../constants';
 import DocumentationUrl from '../DocumentationLink';
 import './bookmarks.scss';
 
-export const addBookmarkItem = ({ setModalOpen }) => (
+export const addBookmarkItem = setModalOpen => (
   <DropdownGroup key="create-bookmark">
     <DropdownItem
       ouiaId="new-bookmark-dropdown-item"
@@ -19,7 +19,10 @@ export const addBookmarkItem = ({ setModalOpen }) => (
       id="newBookmark"
       onClick={setModalOpen}
     >
-      <PlusIcon /> {__('Bookmark this search')}
+      <Icon>
+        <PlusIcon />
+      </Icon>{' '}
+      {__('Bookmark this search')}
     </DropdownItem>
     <DropdownSeparator
       ouiaId="new-bookmark-dropdown-separator"
