@@ -1,6 +1,7 @@
 import React from 'react';
 import PropTypes from 'prop-types';
 import { DropdownItem } from '@patternfly/react-core/deprecated';
+import { Icon } from '@patternfly/react-core';
 import { QuestionCircleIcon } from '@patternfly/react-icons';
 import { newWindowOnClick } from '../../../common/helpers';
 import { translate as __ } from '../../../../react_app/common/I18n';
@@ -11,7 +12,10 @@ const DocumentationLink = ({ href, children }) => (
     key="documentationUrl"
     onClick={newWindowOnClick(href)}
   >
-    <QuestionCircleIcon /> {children}
+    <Icon>
+      <QuestionCircleIcon />
+    </Icon>{' '}
+    {children}
   </DropdownItem>
 );
 
