@@ -1,4 +1,4 @@
-import { testReducerSnapshotWithFixtures } from '@theforeman/test';
+import { testReducerSnapshotWithFixtures } from 'foremanReact/common/testHelpers';
 
 import { default as reducer, initialState } from '../SettingRecordsReducer';
 
