@@ -1,5 +1,5 @@
 import React from 'react';
-import { shallow, mount } from '@theforeman/test';
+import { shallow, mount } from 'enzyme';
 import TimeInput from './TimeInput';
 
 test('TimeInput is working properly', () => {
