@@ -1,5 +1,5 @@
 import React from 'react';
-import { testComponentSnapshotsWithFixtures } from '@theforeman/test';
+import { testComponentSnapshotsWithFixtures } from 'foremanReact/common/testHelpers';
 import SkeletonLoader from '.';
 import { STATUS } from '../../../constants';
 const fixtures = {
