@@ -1,5 +1,5 @@
 import axios from 'axios';
-import { MockAdapter } from '@theforeman/test';
+import MockAdapter from 'axios-mock-adapter';
 
 export const mock = new MockAdapter(axios);
 const methods = {
