@@ -4,7 +4,8 @@ import forceSingleton from '../common/forceSingleton';
 import reducers from './reducers';
 import { middlewares } from './middlewares';
 
-const composeEnhancers = window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || compose;
+export const composeEnhancers =
+  window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || compose;
 
 export const generateStore = () =>
   createStore(reducers, composeEnhancers(applyMiddleware(...middlewares)));
