@@ -6,6 +6,7 @@ import {
   Text,
   TextVariants,
   Button,
+  Icon,
 } from '@patternfly/react-core';
 import { ExternalLinkSquareAltIcon } from '@patternfly/react-icons';
 
@@ -30,7 +31,11 @@ const DocumentationFooter = ({ helpDesc, helpLinkText }) => (
       ouiaId="upgrade-page-help-button"
       component="a"
       variant="link"
-      icon={<ExternalLinkSquareAltIcon />}
+      icon={
+        <Icon>
+          <ExternalLinkSquareAltIcon />
+        </Icon>
+      }
       iconPosition="right"
       target="_blank"
       isInline
